@@ -16,8 +16,18 @@
 #define AWS_HAVE_GCC_INLINE_ASM
 /* #undef AWS_HAVE_MSVC_INTRINSICS_X64 */
 #define AWS_HAVE_POSIX_LARGE_FILE_SUPPORT
-/* #undef AWS_HAVE_EXECINFO */
+#define AWS_HAVE_EXECINFO
 /* #undef AWS_HAVE_WINAPI_DESKTOP */
 #define AWS_HAVE_LINUX_IF_LINK_H
+/* #undef AWS_HAVE_AVX2_INTRINSICS */
+/* #undef AWS_HAVE_AVX512_INTRINSICS */
+/* #undef AWS_HAVE_MM256_EXTRACT_EPI64 */
+/* #undef AWS_HAVE_CLMUL */
+#define AWS_HAVE_ARM32_CRC
+#define AWS_HAVE_ARMv8_1
+/* #undef AWS_ARCH_ARM64 */
+/* #undef AWS_ARCH_INTEL */
+/* #undef AWS_ARCH_INTEL_X64 */
+#define AWS_USE_CPU_EXTENSIONS
 
 #endif
